
// DFPlayer mini MP3 audio playback module Arduino library for FLProg.
// rw6cm 22.11.2017

#include "DFPlayerLite.h"
#include "Arduino.h"
#include "HardwareSerial.h"

uns8 cmd_buffer[10];

void DFPlayerLite::init(HardwareSerial *serial) {
	mySerial = serial;
	mySerial->begin(9600);
	send_command(DFPlayer_RESET);
	delay(5);
}

void DFPlayerLite::send_command(uns8 cmd, uns16 param) {
	cmd_buffer[0] = 0x7E;
	int checksum = 0;
	cmd_buffer[1] = 0xFF;
	cmd_buffer[2] = 0x06;
	cmd_buffer[3] = cmd;
	cmd_buffer[4] = 0x00;
	cmd_buffer[5] = param >> 8;
	cmd_buffer[6] = param & 0xFF;
	for (int i = 1; i < 7; i++) {
		checksum -= cmd_buffer[i];
	}
	cmd_buffer[7] = checksum >> 8;
	cmd_buffer[8] = checksum & 0xFF;
	cmd_buffer[9] = 0xEF;
	for (int i = 0; i < 10; i++) {
		mySerial->write(cmd_buffer[i]);
	}
}

void DFPlayerLite::normal_mode() {
	send_command(DFPlayer_NORMA);
}

void DFPlayerLite::start_track(uns8 folder, uns8 track) {
	if ((folder < 1) || (folder > 10))
		uns16 param = (folder << 8) + (1);
	else {
		uns16 param = (folder << 8) + (track);
		send_command(0x0F, param);
	}
}

void DFPlayerLite::set_volume(uns16 volume){
	if ((volume <= 30) && (volume >= 0))
		send_command(0x06, volume);
	else
		send_command(0x06, 30);
}

void DFPlayerLite::set_EQ(uns16 eq) {
	if ((eq > 5)||(eq < 0))
		send_command(0x07, 0);
	else
		send_command(0x07, eq);
}

void DFPlayerLite::pause() {
	send_command(0x0E, 0);
}
