
// DFPlayer mini MP3 audio playback module Arduino library for FLProg.
// rw6cm 22.11.2017

#include "DFPlayerMega.h"
#include "Arduino.h"
#include "HardwareSerial.h"
#include <SoftwareSerial.h>

uns8 cmd_buffer[10];

static HardwareSerial *_hardware_serial = NULL;
static SoftwareSerial *_software_serial = NULL;

void DFPlayerMega::set_serial(HardwareSerial &theSerial) {
	_hardware_serial = &theSerial;
	myHardSerial = _hardware_serial;
	myHardSerial->begin(9600);
	send_command(DFPlayer_RESET);
	delay(5);
}

void DFPlayerMega::set_serial(SoftwareSerial &theSerial) {
	_software_serial = &theSerial;
	mySoftSerial = _software_serial;
	mySoftSerial->begin(9600);
	send_command(DFPlayer_RESET);
	delay(5);
}

void DFPlayerMega::send_command(uns8 cmd, uns16 param) {
	cmd_buffer[0] = 0x7E;
	int checksum = 0;
	cmd_buffer[1] = 0xFF;
	cmd_buffer[2] = 0x06;
	cmd_buffer[3] = cmd;
	cmd_buffer[4] = 0x00;
	cmd_buffer[5] = param >> 8;
	cmd_buffer[6] = param & 0xFF;
	for (int i = 1; i < 7; i++) {
		checksum -= cmd_buffer[i];
	}
	cmd_buffer[7] = checksum >> 8;
	cmd_buffer[8] = checksum & 0xFF;
	cmd_buffer[9] = 0xEF;
	if (myHardSerial)	{
		for (int i = 0; i < 10; i++) {
		myHardSerial->write(cmd_buffer[i]);}};
	if (mySoftSerial) {
		for (int i = 0; i < 10; i++) {
		mySoftSerial->write(cmd_buffer[i]);}};
}

void DFPlayerMega::normal_mode() {
	send_command(DFPlayer_NORMA);
}

void DFPlayerMega::next_track() {
	send_command(0x01, 0);
}

void DFPlayerMega::previous_track() {
	send_command(0x02, 0);
}

void DFPlayerMega::start_track(uns8 folder, uns8 track) {
	if ((folder < 1) || (folder > 10))
		uns16 param = (folder << 8) + (1);
	else {
		uns16 param = (folder << 8) + (track);
		send_command(0x0F, param);
	}
}

void DFPlayerMega::volume_up() {
	send_command(0x04, 0);
}

void DFPlayerMega::volume_down() {
	send_command(0x05, 0);
}

void DFPlayerMega::set_volume(uns16 volume){
	if ((volume <= 30) && (volume >= 0))
		send_command(0x06, volume);
}

void DFPlayerMega::set_EQ(uns16 eq) {
	if ((eq > 5)||(eq < 0))
		send_command(0x07, 0);
	else
		send_command(0x07, eq);
}

void DFPlayerMega::set_replay(uns16 mode) {
	if (mode < 4)
		send_command(0x08, mode);
		send_command(0x08, 0);
}

void DFPlayerMega::pause() {
	send_command(0x0E, 0);
}

void DFPlayerMega::repeat_play(uns16 repeat) {
	send_command(0x11, repeat);
}

void DFPlayerMega::random_play() {
	send_command(0x18, 0);
}